@@ -1,18 +1,30 @@
 # This file is part of ReText
-# Copyright: Dmitry Shachnev 2012-2014
-# License: GNU GPL v2 or higher
+# Copyright: 2012-2014 Dmitry Shachnev
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import markups
 import markups.common
-from os.path import join, abspath
+from os.path import dirname, exists, join
 
 from PyQt5.QtCore import QByteArray, QLocale, QSettings, QStandardPaths
 from PyQt5.QtGui import QFont
 
-app_name = "ReText"
-app_version = "5.0.2"
+app_version = "5.3.1"
 
 settings = QSettings('ReText project', 'ReText')
+print('Using configuration file:', settings.fileName())
 
 if not str(settings.fileName()).endswith('.conf'):
 	# We are on Windows probably
@@ -32,31 +44,34 @@ else:
 	except enchant.errors.Error:
 		enchant_available = False
 
-icon_path = "icons/"
+datadirs = QStandardPaths.standardLocations(QStandardPaths.GenericDataLocation)
+datadirs = [join(d, 'retext') for d in datadirs]
 
-DOCTYPE_NONE = ''
-DOCTYPE_MARKDOWN = markups.MarkdownMarkup.name
-DOCTYPE_REST = markups.ReStructuredTextMarkup.name
-DOCTYPE_HTML = 'html'
+if '__file__' in locals():
+	datadirs = [dirname(dirname(__file__))] + datadirs
+
+icon_path = 'icons/'
+for dir in datadirs:
+	if exists(join(dir, 'icons')):
+		icon_path = join(dir, 'icons/')
+		break
 
 configOptions = {
 	'appStyleSheet': '',
-	'autoPlainText': True,
 	'autoSave': False,
-	'colorSchemeFile': '',
+	'defaultCodec': '',
 	'defaultMarkup': '',
-	'editorFont': 'monospace',
-	'editorFontSize': 0,
-	'font': '',
-	'fontSize': 0,
-	'iconTheme': '',
+	'editorFont': QFont('monospace'),
+	'font': QFont(),
 	'handleWebLinks': False,
 	'hideToolBar': False,
 	'highlightCurrentLine': False,
+	'iconTheme': '',
 	'lineNumbersEnabled': False,
-	'previewState': False,
+	'livePreviewByDefault': False,
+	'markdownDefaultFileExtension': '.mkd',
 	'pygmentsStyle': 'default',
-	'restorePreviewState': False,
+	'restDefaultFileExtension': '.rst',
 	'rightMargin': 0,
 	'saveWindowGeometry': False,
 	'spellCheck': False,
@@ -65,11 +80,16 @@ configOptions = {
 	'tabInsertsSpaces': True,
 	'tabWidth': 4,
 	'uiLanguage': QLocale.system().name(),
+	'useFakeVim': False,
 	'useWebKit': False,
 	'windowGeometry': QByteArray(),
 }
 
 def readFromSettings(key, keytype, settings=settings, default=None):
+	if isinstance(default, QFont):
+		family = readFromSettings(key, str, settings, default.family())
+		size = readFromSettings(key + 'Size', int, settings, 0)
+		return QFont(family, size)
 	if not settings.contains(key):
 		return default
 	try:
@@ -93,7 +113,10 @@ def readListFromSettings(key, settings=settings):
 		return value
 
 def writeToSettings(key, value, default, settings=settings):
-	if value == default:
+	if isinstance(value, QFont):
+		writeToSettings(key, value.family(), '', settings)
+		writeToSettings(key + 'Size', max(value.pointSize(), 0), 0, settings)
+	elif value == default:
 		settings.remove(key)
 	else:
 		settings.setValue(key, value)
@@ -122,11 +145,3 @@ class ReTextSettings(object):
 globalSettings = ReTextSettings()
 
 markups.common.PYGMENTS_STYLE = globalSettings.pygmentsStyle
-
-monofont = QFont()
-monofont.setFamily(globalSettings.editorFont)
-if globalSettings.editorFontSize:
-	monofont.setPointSize(globalSettings.editorFontSize)
-
-datadirs = QStandardPaths.standardLocations(QStandardPaths.GenericDataLocation)
-datadirs = [abspath('.')] + [join(d, 'retext') for d in datadirs]
