@@ -3,82 +3,72 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Behavior</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Automatically save documents</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Restore window geometry</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
-        <source>Restore live preview state</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Open external links in ReText window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Editor</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Highlight current line</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Show line numbers</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Tab key inserts spaces</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Tabulation width</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Display right margin at column</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Interface</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Icon theme name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
-        <source>Color scheme file</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Stylesheet file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Markdown syntax extensions (comma-separated)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -87,16 +77,21 @@
         <source>Help</source>
         <translation type="unfinished">Ajuda</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Use live preview by default</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
     <message>
-        <location filename="config.py" line="33"/>
+        <location filename="config.py" line="34"/>
         <source>(none)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="40"/>
+        <location filename="config.py" line="41"/>
         <source>Select file to open</source>
         <translation type="unfinished"></translation>
     </message>
@@ -128,425 +123,433 @@
     </message>
 </context>
 <context>
-    <name>ReTextWindow</name>
+    <name>ReTextTab</name>
     <message>
-        <location filename="window.py" line="82"/>
-        <source>File toolbar</source>
-        <translation>Barra d&apos;eines Fitxer</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="84"/>
-        <source>Edit toolbar</source>
-        <translation>Barra d&apos;eines Edita</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="86"/>
-        <source>Search toolbar</source>
-        <translation>Barra d&apos;eines de Cerca</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="90"/>
-        <source>New</source>
-        <translation>Nou</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="93"/>
-        <source>Open</source>
-        <translation>Obre</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="101"/>
-        <source>Save</source>
-        <translation>Desa</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="105"/>
-        <source>Save as</source>
-        <translation>Anomena i desa</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="111"/>
-        <source>Print</source>
-        <translation>Imprimeix</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="114"/>
-        <source>Print preview</source>
-        <translation>Imprimeix la vista prèvia</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="116"/>
-        <source>View HTML code</source>
-        <translation>Veure el codi HTML</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="121"/>
-        <source>Find text</source>
-        <translation>Cerca el text</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="125"/>
-        <source>Preview</source>
-        <translation>Vista prèvia</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="135"/>
-        <source>Live preview</source>
-        <translation>Vista prèvia en directe</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="145"/>
-        <source>Fullscreen mode</source>
-        <translation>Mode de pantalla completa</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="155"/>
-        <source>Quit</source>
-        <translation>Surt</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="158"/>
-        <source>Undo</source>
-        <translation>Desfés</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="160"/>
-        <source>Redo</source>
-        <translation>Refés</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="162"/>
-        <source>Copy</source>
-        <translation>Copia</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="164"/>
-        <source>Cut</source>
-        <translation>Retalla</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="166"/>
-        <source>Paste</source>
-        <translation>Enganxa</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="176"/>
-        <source>Enable</source>
-        <translation>Activa</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="177"/>
-        <source>Set locale</source>
-        <translation>Estableix l&apos;idioma</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="178"/>
-        <source>Use WebKit renderer</source>
-        <translation>Utilitza el renderitzador WebKit</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="181"/>
-        <source>Next</source>
-        <translation>Següent</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="183"/>
-        <source>Previous</source>
-        <translation>Previ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="185"/>
-        <source>Get help online</source>
-        <translation>Obtingueu ajuda en línia</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="186"/>
-        <source>About ReText</source>
-        <translation>Sobre ReText</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="189"/>
-        <source>About Qt</source>
-        <translation>Sobre Qt</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="209"/>
-        <source>Bold</source>
-        <translation>Negreta</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="211"/>
-        <source>Italic</source>
-        <translation>Cursiva</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="213"/>
-        <source>Underline</source>
-        <translation>Subratllat</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="221"/>
-        <source>Tags</source>
-        <translation>Etiquetes</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="225"/>
-        <source>Symbols</source>
-        <translation>Símbols</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="232"/>
-        <source>File</source>
-        <translation>Fitxer</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="233"/>
-        <source>Edit</source>
-        <translation>Edita</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="234"/>
-        <source>Help</source>
-        <translation>Ajuda</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="237"/>
-        <source>Open recent</source>
-        <translation>Obre recents</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="250"/>
-        <source>Export</source>
-        <translation>Exporta</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="271"/>
-        <source>Spell check</source>
-        <translation>Comprova l&apos;ortografia</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="282"/>
-        <source>Formatting</source>
-        <translation>Formata</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="323"/>
-        <source>Search</source>
-        <translation>Cerca</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="325"/>
-        <source>Case sensitively</source>
-        <translation>Majúscules i minúscules</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1141"/>
+        <location filename="tab.py" line="115"/>
         <source>New document</source>
         <translation>Document nou</translation>
     </message>
     <message>
-        <location filename="window.py" line="685"/>
+        <location filename="tab.py" line="121"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation>No s&apos;ha pogut analitzar el contingut del fitxer. Comproveu que teniu instal·lat el  &lt;a href=&quot;%s&quot;&gt;mòdul  necessari&lt;/a&gt;.</translation>
     </message>
+</context>
+<context>
+    <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="748"/>
+        <location filename="window.py" line="69"/>
+        <source>File toolbar</source>
+        <translation>Barra d&apos;eines Fitxer</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="71"/>
+        <source>Edit toolbar</source>
+        <translation>Barra d&apos;eines Edita</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="73"/>
+        <source>Search toolbar</source>
+        <translation>Barra d&apos;eines de Cerca</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="77"/>
+        <source>New</source>
+        <translation>Nou</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="80"/>
+        <source>Open</source>
+        <translation>Obre</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="89"/>
+        <source>Save</source>
+        <translation>Desa</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="93"/>
+        <source>Save as</source>
+        <translation>Anomena i desa</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="99"/>
+        <source>Print</source>
+        <translation>Imprimeix</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="102"/>
+        <source>Print preview</source>
+        <translation>Imprimeix la vista prèvia</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="104"/>
+        <source>View HTML code</source>
+        <translation>Veure el codi HTML</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="109"/>
+        <source>Find text</source>
+        <translation>Cerca el text</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="113"/>
+        <source>Preview</source>
+        <translation>Vista prèvia</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="123"/>
+        <source>Live preview</source>
+        <translation>Vista prèvia en directe</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="136"/>
+        <source>Fullscreen mode</source>
+        <translation>Mode de pantalla completa</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="146"/>
+        <source>Quit</source>
+        <translation>Surt</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="149"/>
+        <source>Undo</source>
+        <translation>Desfés</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="151"/>
+        <source>Redo</source>
+        <translation>Refés</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="153"/>
+        <source>Copy</source>
+        <translation>Copia</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="155"/>
+        <source>Cut</source>
+        <translation>Retalla</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="157"/>
+        <source>Paste</source>
+        <translation>Enganxa</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="167"/>
+        <source>Enable</source>
+        <translation>Activa</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="168"/>
+        <source>Set locale</source>
+        <translation>Estableix l&apos;idioma</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="169"/>
+        <source>Use WebKit renderer</source>
+        <translation>Utilitza el renderitzador WebKit</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="172"/>
+        <source>Next</source>
+        <translation>Següent</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="174"/>
+        <source>Previous</source>
+        <translation>Previ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="176"/>
+        <source>Get help online</source>
+        <translation>Obtingueu ajuda en línia</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="177"/>
+        <source>About ReText</source>
+        <translation>Sobre ReText</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="180"/>
+        <source>About Qt</source>
+        <translation>Sobre Qt</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="200"/>
+        <source>Bold</source>
+        <translation>Negreta</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="202"/>
+        <source>Italic</source>
+        <translation>Cursiva</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="204"/>
+        <source>Underline</source>
+        <translation>Subratllat</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="212"/>
+        <source>Tags</source>
+        <translation>Etiquetes</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="216"/>
+        <source>Symbols</source>
+        <translation>Símbols</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="223"/>
+        <source>File</source>
+        <translation>Fitxer</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="224"/>
+        <source>Edit</source>
+        <translation>Edita</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="225"/>
+        <source>Help</source>
+        <translation>Ajuda</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="228"/>
+        <source>Open recent</source>
+        <translation>Obre recents</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="241"/>
+        <source>Export</source>
+        <translation>Exporta</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="262"/>
+        <source>Spell check</source>
+        <translation>Comprova l&apos;ortografia</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="273"/>
+        <source>Formatting</source>
+        <translation>Formata</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="313"/>
+        <source>Search</source>
+        <translation>Cerca</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="315"/>
+        <source>Case sensitively</source>
+        <translation>Majúscules i minúscules</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="442"/>
+        <source>New document</source>
+        <translation>Document nou</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="591"/>
         <source>Please, save the file somewhere.</source>
         <translation>deseu el fitxer en algun directori</translation>
     </message>
     <message>
-        <location filename="window.py" line="180"/>
+        <location filename="window.py" line="171"/>
         <source>Show directory</source>
         <translation>Mostra el directori</translation>
     </message>
     <message>
-        <location filename="window.py" line="868"/>
+        <location filename="window.py" line="711"/>
         <source>Select one or several files to open</source>
         <translation>Seleccioneu un o més fitxers per obrir</translation>
     </message>
     <message>
-        <location filename="window.py" line="868"/>
+        <location filename="window.py" line="711"/>
         <source>Supported files</source>
         <translation>Fitxers suportats</translation>
     </message>
     <message>
-        <location filename="window.py" line="868"/>
+        <location filename="window.py" line="711"/>
         <source>All files (*)</source>
         <translation>Tots els fitxers (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="952"/>
+        <location filename="window.py" line="770"/>
         <source>Plain text (*.txt)</source>
         <translation>Text pla (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="955"/>
+        <location filename="window.py" line="773"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>%s fitxers</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="window.py" line="844"/>
         <source>Save file</source>
         <translation>Desa el fitxer</translation>
     </message>
     <message>
-        <location filename="window.py" line="982"/>
+        <location filename="window.py" line="799"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>No s&apos;ha pogut desar el fitxer perquè només és de lectura</translation>
     </message>
     <message>
-        <location filename="window.py" line="1030"/>
+        <location filename="window.py" line="834"/>
         <source>Export document to ODT</source>
         <translation>Exporta el document a ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="1030"/>
+        <location filename="window.py" line="834"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Fitxers de text OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="window.py" line="844"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Fitxers HTML (*.html *htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1062"/>
+        <location filename="window.py" line="866"/>
         <source>Export document to PDF</source>
         <translation>Exporta document com a PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="1062"/>
+        <location filename="window.py" line="866"/>
         <source>PDF files (*.pdf)</source>
         <translation>Fitxers PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1079"/>
+        <location filename="window.py" line="883"/>
         <source>Print document</source>
         <translation>Imprimeix document</translation>
     </message>
     <message>
-        <location filename="window.py" line="1100"/>
+        <location filename="window.py" line="904"/>
         <source>Export document</source>
         <translation>Exporta document</translation>
     </message>
     <message>
-        <location filename="window.py" line="1119"/>
+        <location filename="window.py" line="923"/>
         <source>Failed to execute the command:</source>
         <translation>S&apos;ha produït un error a l&apos;executar el comandament:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1237"/>
+        <location filename="window.py" line="1030"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>S&apos;ha modificat el document.
 Voleu desar els canvis?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1261"/>
+        <location filename="window.py" line="1055"/>
         <source>HTML code</source>
         <translation>Codi HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Editor de Markdown i reStructuredText senzill alhora que potent</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Autor: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>Website</source>
         <translation>Lloc web</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>Markdown syntax</source>
         <translation>Sintaxi markdown</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>reStructuredText syntax</source>
         <translation>Sintaxi reStructuredText</translation>
     </message>
     <message>
-        <location filename="window.py" line="279"/>
+        <location filename="window.py" line="270"/>
         <source>Default markup</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="592"/>
+        <location filename="window.py" line="503"/>
         <source>Preferences</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="96"/>
+        <location filename="window.py" line="83"/>
         <source>Set encoding</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="927"/>
+        <location filename="window.py" line="750"/>
         <source>Select file encoding from the list:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1217"/>
+        <location filename="window.py" line="1009"/>
         <source>Reload</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="107"/>
+        <location filename="window.py" line="95"/>
         <source>Next tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="109"/>
+        <location filename="window.py" line="97"/>
         <source>Previous tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="137"/>
+        <location filename="window.py" line="128"/>
         <source>Table mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="140"/>
+        <location filename="window.py" line="131"/>
         <source>FakeVim mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1200"/>
+        <location filename="window.py" line="992"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1208"/>
+        <location filename="window.py" line="1000"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1213"/>
+        <location filename="window.py" line="1005"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="117"/>
+        <location filename="window.py" line="105"/>
         <source>Change editor font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="119"/>
+        <location filename="window.py" line="107"/>
         <source>Change preview font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>ReText %s (using PyMarkups %s)</source>
         <translation type="unfinished"></translation>
     </message>
