@@ -3,82 +3,72 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Behavior</source>
         <translation>Comportement</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Automatically save documents</source>
         <translation>Sauvegarde automatique des documents</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Restore window geometry</source>
         <translation>Restaurer la taille de la fenêtre</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
-        <source>Restore live preview state</source>
-        <translation>Restaurer l&apos;état de l&apos;aperçu direct</translation>
-    </message>
-    <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Open external links in ReText window</source>
         <translation>Ouvrir les liens externes dans la fenêtre de ReText</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Markdown syntax extensions (comma-separated)</source>
         <translation>Extensions liées à la syntaxe Markdown (séparées par une virgule)</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Editor</source>
         <translation>Éditeur</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Highlight current line</source>
         <translation>Surligner la ligne courante</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Show line numbers</source>
         <translation>Afficher les numéros de ligne</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Tab key inserts spaces</source>
         <translation>La touche Tab insère des espaces</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Tabulation width</source>
         <translation>Largeur de tabulation</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Display right margin at column</source>
         <translation>Afficher la marge de droite à la colonne</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Interface</source>
         <translation>Interface</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Icon theme name</source>
         <translation>Nom du thème d’icônes</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
-        <source>Color scheme file</source>
-        <translation>Fichier de thème de couleur</translation>
-    </message>
-    <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Stylesheet file</source>
         <translation>Fichier de feuille de style</translation>
     </message>
@@ -87,16 +77,21 @@
         <source>Help</source>
         <translation>Aide</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Use live preview by default</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
     <message>
-        <location filename="config.py" line="33"/>
+        <location filename="config.py" line="34"/>
         <source>(none)</source>
         <translation>(aucun)</translation>
     </message>
     <message>
-        <location filename="config.py" line="40"/>
+        <location filename="config.py" line="41"/>
         <source>Select file to open</source>
         <translation>Choisir le fichier à ouvrir</translation>
     </message>
@@ -128,367 +123,375 @@
     </message>
 </context>
 <context>
-    <name>ReTextWindow</name>
+    <name>ReTextTab</name>
     <message>
-        <location filename="window.py" line="82"/>
-        <source>File toolbar</source>
-        <translation>Barre d&apos;outil Fichier</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="84"/>
-        <source>Edit toolbar</source>
-        <translation>Barre d&apos;outil Édition</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="86"/>
-        <source>Search toolbar</source>
-        <translation>Barre d&apos;outil de recherche</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="90"/>
-        <source>New</source>
-        <translation>Nouveau</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="93"/>
-        <source>Open</source>
-        <translation>Ouvrir</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="96"/>
-        <source>Set encoding</source>
-        <translation>Définir l&apos;encodage</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1217"/>
-        <source>Reload</source>
-        <translation>Recherger</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="101"/>
-        <source>Save</source>
-        <translation>Enregistrer</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="105"/>
-        <source>Save as</source>
-        <translation>Enregistrer Sous</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="107"/>
-        <source>Next tab</source>
-        <translation>Onglet suivant</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="109"/>
-        <source>Previous tab</source>
-        <translation>Onglet précédent</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="111"/>
-        <source>Print</source>
-        <translation>Imprimer</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="114"/>
-        <source>Print preview</source>
-        <translation>Aperçu avant impression</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="116"/>
-        <source>View HTML code</source>
-        <translation>Voir le code HTML</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="121"/>
-        <source>Find text</source>
-        <translation>Rechercher un texte</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="125"/>
-        <source>Preview</source>
-        <translation>Aperçu</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="135"/>
-        <source>Live preview</source>
-        <translation>Aperçu direct</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="137"/>
-        <source>Table mode</source>
-        <translation>Mode table</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="140"/>
-        <source>FakeVim mode</source>
-        <translation>Imitation de Vim</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="145"/>
-        <source>Fullscreen mode</source>
-        <translation>Mode plein écran</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="592"/>
-        <source>Preferences</source>
-        <translation>Préférences</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="155"/>
-        <source>Quit</source>
-        <translation>Quitter</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="158"/>
-        <source>Undo</source>
-        <translation>Annuler</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="160"/>
-        <source>Redo</source>
-        <translation>Rétablir</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="162"/>
-        <source>Copy</source>
-        <translation>Copier</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="164"/>
-        <source>Cut</source>
-        <translation>Couper</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="166"/>
-        <source>Paste</source>
-        <translation>Coller</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="176"/>
-        <source>Enable</source>
-        <translation>Activer</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="177"/>
-        <source>Set locale</source>
-        <translation>Choisir la langue</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="178"/>
-        <source>Use WebKit renderer</source>
-        <translation>Utiliser le rendu de WebKit</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="180"/>
-        <source>Show directory</source>
-        <translation>Afficher le répertoire</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="181"/>
-        <source>Next</source>
-        <translation>Suivant</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="183"/>
-        <source>Previous</source>
-        <translation>Précédent</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="185"/>
-        <source>Get help online</source>
-        <translation>Assistance en ligne</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="186"/>
-        <source>About ReText</source>
-        <translation>À propos de ReText</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="189"/>
-        <source>About Qt</source>
-        <translation>À propos de Qt</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="209"/>
-        <source>Bold</source>
-        <translation>Gras</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="211"/>
-        <source>Italic</source>
-        <translation>Italique</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="213"/>
-        <source>Underline</source>
-        <translation>Souligné</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="221"/>
-        <source>Tags</source>
-        <translation>Mots-clefs</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="225"/>
-        <source>Symbols</source>
-        <translation>Symboles</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="232"/>
-        <source>File</source>
-        <translation>Fichier</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="233"/>
-        <source>Edit</source>
-        <translation>Édition</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="234"/>
-        <source>Help</source>
-        <translation>Aide</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="237"/>
-        <source>Open recent</source>
-        <translation>Ouvrir les fichiers récents</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="250"/>
-        <source>Export</source>
-        <translation>Exporter</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="271"/>
-        <source>Spell check</source>
-        <translation>Vérifier l&apos;orthographe</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="279"/>
-        <source>Default markup</source>
-        <translation>Balisage par défaut</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="282"/>
-        <source>Formatting</source>
-        <translation>Formatage</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="323"/>
-        <source>Search</source>
-        <translation>Rechercher</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="325"/>
-        <source>Case sensitively</source>
-        <translation>Sensible à la casse</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1141"/>
+        <location filename="tab.py" line="115"/>
         <source>New document</source>
         <translation>Nouveau document</translation>
     </message>
     <message>
-        <location filename="window.py" line="685"/>
+        <location filename="tab.py" line="121"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation>Impossible d&apos;analyser le contenu du fichier, vérifier si les &lt;a href=&quot;%s&quot;&gt;modules nécessaires&lt;/a&gt; sont installés!</translation>
     </message>
+</context>
+<context>
+    <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="748"/>
+        <location filename="window.py" line="69"/>
+        <source>File toolbar</source>
+        <translation>Barre d&apos;outil Fichier</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="71"/>
+        <source>Edit toolbar</source>
+        <translation>Barre d&apos;outil Édition</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="73"/>
+        <source>Search toolbar</source>
+        <translation>Barre d&apos;outil de recherche</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="77"/>
+        <source>New</source>
+        <translation>Nouveau</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="80"/>
+        <source>Open</source>
+        <translation>Ouvrir</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="83"/>
+        <source>Set encoding</source>
+        <translation>Définir l&apos;encodage</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1009"/>
+        <source>Reload</source>
+        <translation>Recherger</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="89"/>
+        <source>Save</source>
+        <translation>Enregistrer</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="93"/>
+        <source>Save as</source>
+        <translation>Enregistrer Sous</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="95"/>
+        <source>Next tab</source>
+        <translation>Onglet suivant</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="97"/>
+        <source>Previous tab</source>
+        <translation>Onglet précédent</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="99"/>
+        <source>Print</source>
+        <translation>Imprimer</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="102"/>
+        <source>Print preview</source>
+        <translation>Aperçu avant impression</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="104"/>
+        <source>View HTML code</source>
+        <translation>Voir le code HTML</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="109"/>
+        <source>Find text</source>
+        <translation>Rechercher un texte</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="113"/>
+        <source>Preview</source>
+        <translation>Aperçu</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="123"/>
+        <source>Live preview</source>
+        <translation>Aperçu direct</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="128"/>
+        <source>Table mode</source>
+        <translation>Mode table</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="131"/>
+        <source>FakeVim mode</source>
+        <translation>Imitation de Vim</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="136"/>
+        <source>Fullscreen mode</source>
+        <translation>Mode plein écran</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="503"/>
+        <source>Preferences</source>
+        <translation>Préférences</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="146"/>
+        <source>Quit</source>
+        <translation>Quitter</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="149"/>
+        <source>Undo</source>
+        <translation>Annuler</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="151"/>
+        <source>Redo</source>
+        <translation>Rétablir</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="153"/>
+        <source>Copy</source>
+        <translation>Copier</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="155"/>
+        <source>Cut</source>
+        <translation>Couper</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="157"/>
+        <source>Paste</source>
+        <translation>Coller</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="167"/>
+        <source>Enable</source>
+        <translation>Activer</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="168"/>
+        <source>Set locale</source>
+        <translation>Choisir la langue</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="169"/>
+        <source>Use WebKit renderer</source>
+        <translation>Utiliser le rendu de WebKit</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="171"/>
+        <source>Show directory</source>
+        <translation>Afficher le répertoire</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="172"/>
+        <source>Next</source>
+        <translation>Suivant</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="174"/>
+        <source>Previous</source>
+        <translation>Précédent</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="176"/>
+        <source>Get help online</source>
+        <translation>Assistance en ligne</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="177"/>
+        <source>About ReText</source>
+        <translation>À propos de ReText</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="180"/>
+        <source>About Qt</source>
+        <translation>À propos de Qt</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="200"/>
+        <source>Bold</source>
+        <translation>Gras</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="202"/>
+        <source>Italic</source>
+        <translation>Italique</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="204"/>
+        <source>Underline</source>
+        <translation>Souligné</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="212"/>
+        <source>Tags</source>
+        <translation>Mots-clefs</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="216"/>
+        <source>Symbols</source>
+        <translation>Symboles</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="223"/>
+        <source>File</source>
+        <translation>Fichier</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="224"/>
+        <source>Edit</source>
+        <translation>Édition</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="225"/>
+        <source>Help</source>
+        <translation>Aide</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="228"/>
+        <source>Open recent</source>
+        <translation>Ouvrir les fichiers récents</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="241"/>
+        <source>Export</source>
+        <translation>Exporter</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="262"/>
+        <source>Spell check</source>
+        <translation>Vérifier l&apos;orthographe</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="270"/>
+        <source>Default markup</source>
+        <translation>Balisage par défaut</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="273"/>
+        <source>Formatting</source>
+        <translation>Formatage</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="313"/>
+        <source>Search</source>
+        <translation>Rechercher</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="315"/>
+        <source>Case sensitively</source>
+        <translation>Sensible à la casse</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="442"/>
+        <source>New document</source>
+        <translation>Nouveau document</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="591"/>
         <source>Please, save the file somewhere.</source>
         <translation>Veuillez enregistrer le fichier quelque part.</translation>
     </message>
     <message>
-        <location filename="window.py" line="868"/>
+        <location filename="window.py" line="711"/>
         <source>Select one or several files to open</source>
         <translation>Choisir un ou plusieurs fichiers à ouvrir</translation>
     </message>
     <message>
-        <location filename="window.py" line="868"/>
+        <location filename="window.py" line="711"/>
         <source>Supported files</source>
         <translation>Formats acceptés</translation>
     </message>
     <message>
-        <location filename="window.py" line="868"/>
+        <location filename="window.py" line="711"/>
         <source>All files (*)</source>
         <translation>Tous les fichiers (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="927"/>
+        <location filename="window.py" line="750"/>
         <source>Select file encoding from the list:</source>
         <translation>Choisir l&apos;encodage du fichier dans la liste</translation>
     </message>
     <message>
-        <location filename="window.py" line="952"/>
+        <location filename="window.py" line="770"/>
         <source>Plain text (*.txt)</source>
         <translation>Fichiers texte (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="955"/>
+        <location filename="window.py" line="773"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>Fichers %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="window.py" line="844"/>
         <source>Save file</source>
         <translation>Enregistrer le fichier</translation>
     </message>
     <message>
-        <location filename="window.py" line="982"/>
+        <location filename="window.py" line="799"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Impossible d&apos;enregistrer le fichier car il est en lecture seule !</translation>
     </message>
     <message>
-        <location filename="window.py" line="1030"/>
+        <location filename="window.py" line="834"/>
         <source>Export document to ODT</source>
         <translation>Exporter le document au format ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="1030"/>
+        <location filename="window.py" line="834"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Fichiers OpenDocument texte (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="window.py" line="844"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Fichiers HTML (*.html, *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1062"/>
+        <location filename="window.py" line="866"/>
         <source>Export document to PDF</source>
         <translation>Exporter le document au format PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="1062"/>
+        <location filename="window.py" line="866"/>
         <source>PDF files (*.pdf)</source>
         <translation>Fichiers PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1079"/>
+        <location filename="window.py" line="883"/>
         <source>Print document</source>
         <translation>Imprimer le document</translation>
     </message>
     <message>
-        <location filename="window.py" line="1100"/>
+        <location filename="window.py" line="904"/>
         <source>Export document</source>
         <translation>Exporter le document</translation>
     </message>
     <message>
-        <location filename="window.py" line="1119"/>
+        <location filename="window.py" line="923"/>
         <source>Failed to execute the command:</source>
         <translation>Échec lors de l&apos;exécution de la commande :</translation>
     </message>
     <message>
-        <location filename="window.py" line="1200"/>
+        <location filename="window.py" line="992"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
         <translation>Ce fichier a été supprimé par une autre application.
 Pensez à vérifier que vous sauvegardez le fichier avant de quitter.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1208"/>
+        <location filename="window.py" line="1000"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
@@ -497,59 +500,59 @@ Voulez-vous recharger le fichier (vos modifications seront perdues) ?
 </translation>
     </message>
     <message>
-        <location filename="window.py" line="1213"/>
+        <location filename="window.py" line="1005"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
         <translation>Si vous choisissez de ne pas recharger le fichier, la sauvegarde automatique sera désactivée pour cette session afin d&apos;éviter une perte de données.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1237"/>
+        <location filename="window.py" line="1030"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Le document a été modifié.
 Voulez vous enregistrer vos changements ?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1261"/>
+        <location filename="window.py" line="1055"/>
         <source>HTML code</source>
         <translation>Code HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Éditeur de Markdown et reStructuredText simple mais puissant</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Auteur: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>Website</source>
         <translation>Site Web</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>Markdown syntax</source>
         <translation>Syntaxe Markdown</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>reStructuredText syntax</source>
         <translation>Syntaxe reStructuredText</translation>
     </message>
     <message>
-        <location filename="window.py" line="117"/>
+        <location filename="window.py" line="105"/>
         <source>Change editor font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="119"/>
+        <location filename="window.py" line="107"/>
         <source>Change preview font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>ReText %s (using PyMarkups %s)</source>
         <translation type="unfinished"></translation>
     </message>
