@@ -3,82 +3,72 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Behavior</source>
         <translation>動作設定</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Automatically save documents</source>
         <translation>文書を自動保存する</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Restore window geometry</source>
         <translation>ウィンドウの表示位置を記憶する</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
-        <source>Restore live preview state</source>
-        <translation>ライブプレビューの状態を記憶する</translation>
-    </message>
-    <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Open external links in ReText window</source>
         <translation>外部リンクを ReText ウィンドウ内で開く</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Markdown syntax extensions (comma-separated)</source>
         <translation>Markdown記法の拡張(カンマ区切り)</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Editor</source>
         <translation>エディタ</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Highlight current line</source>
         <translation>カーソル行をハイライト表示する</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Show line numbers</source>
         <translation>行番号を表示する</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Tab key inserts spaces</source>
         <translation>タブをスペースに展開</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Tabulation width</source>
         <translation>タブの桁数</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Display right margin at column</source>
         <translation>右マージン表示桁</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Interface</source>
         <translation>外観</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Icon theme name</source>
         <translation>アイコンテーマ名</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
-        <source>Color scheme file</source>
-        <translation>カラースキーマファイル</translation>
-    </message>
-    <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Stylesheet file</source>
         <translation>スタイルシートファイル</translation>
     </message>
@@ -87,16 +77,21 @@
         <source>Help</source>
         <translation>ヘルプ</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Use live preview by default</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
     <message>
-        <location filename="config.py" line="33"/>
+        <location filename="config.py" line="34"/>
         <source>(none)</source>
         <translation>（未設定）</translation>
     </message>
     <message>
-        <location filename="config.py" line="40"/>
+        <location filename="config.py" line="41"/>
         <source>Select file to open</source>
         <translation>ファイルを開く</translation>
     </message>
@@ -128,377 +123,385 @@
     </message>
 </context>
 <context>
-    <name>ReTextWindow</name>
+    <name>ReTextTab</name>
     <message>
-        <location filename="window.py" line="82"/>
-        <source>File toolbar</source>
-        <translation>ファイルツールバー</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="84"/>
-        <source>Edit toolbar</source>
-        <translation>編集ツールバー</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="86"/>
-        <source>Search toolbar</source>
-        <translation>検索ツールバー</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="90"/>
-        <source>New</source>
-        <translation>新規</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="93"/>
-        <source>Open</source>
-        <translation>開く</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="96"/>
-        <source>Set encoding</source>
-        <translation>文字エンコーディング</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1217"/>
-        <source>Reload</source>
-        <translation>再読み込み</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="101"/>
-        <source>Save</source>
-        <translation>保存</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="105"/>
-        <source>Save as</source>
-        <translation>名前を付けて保存</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="107"/>
-        <source>Next tab</source>
-        <translation>次のタブへ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="109"/>
-        <source>Previous tab</source>
-        <translation>前のタブへ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="111"/>
-        <source>Print</source>
-        <translation>印刷</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="114"/>
-        <source>Print preview</source>
-        <translation>印刷プレビュー</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="116"/>
-        <source>View HTML code</source>
-        <translation>HTMLコードを表示</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="117"/>
-        <source>Change editor font</source>
-        <translation>エディターのフォントを変更</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="119"/>
-        <source>Change preview font</source>
-        <translation>プレビューのフォントを変更</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="121"/>
-        <source>Find text</source>
-        <translation>テキストを検索</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="125"/>
-        <source>Preview</source>
-        <translation>プレビュー</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="135"/>
-        <source>Live preview</source>
-        <translation>ライブプレビュー</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="137"/>
-        <source>Table mode</source>
-        <translation>表組みモード</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="140"/>
-        <source>FakeVim mode</source>
-        <translation>擬似Vimモード</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="145"/>
-        <source>Fullscreen mode</source>
-        <translation>フルスクリーンモード</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="592"/>
-        <source>Preferences</source>
-        <translation>設定</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="155"/>
-        <source>Quit</source>
-        <translation>終了</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="158"/>
-        <source>Undo</source>
-        <translation>元に戻す</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="160"/>
-        <source>Redo</source>
-        <translation>やり直す</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="162"/>
-        <source>Copy</source>
-        <translation>コピー</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="164"/>
-        <source>Cut</source>
-        <translation>切り取り</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="166"/>
-        <source>Paste</source>
-        <translation>貼り付け</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="176"/>
-        <source>Enable</source>
-        <translation>有効</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="177"/>
-        <source>Set locale</source>
-        <translation>ロケールの設定</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="178"/>
-        <source>Use WebKit renderer</source>
-        <translation>WebKitレンダラーを使用</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="180"/>
-        <source>Show directory</source>
-        <translation>ディレクトリを表示</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="181"/>
-        <source>Next</source>
-        <translation>次へ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="183"/>
-        <source>Previous</source>
-        <translation>前へ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="185"/>
-        <source>Get help online</source>
-        <translation>オンラインでヘルプを読む</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="186"/>
-        <source>About ReText</source>
-        <translation>ReTextについて</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="189"/>
-        <source>About Qt</source>
-        <translation>Qtについて</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="209"/>
-        <source>Bold</source>
-        <translation>太字</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="211"/>
-        <source>Italic</source>
-        <translation>斜体</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="213"/>
-        <source>Underline</source>
-        <translation>下線</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="221"/>
-        <source>Tags</source>
-        <translation>タグ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="225"/>
-        <source>Symbols</source>
-        <translation>シンボル</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="232"/>
-        <source>File</source>
-        <translation>ファイル</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="233"/>
-        <source>Edit</source>
-        <translation>編集</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="234"/>
-        <source>Help</source>
-        <translation>ヘルプ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="237"/>
-        <source>Open recent</source>
-        <translation>最近使用したファイル</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="250"/>
-        <source>Export</source>
-        <translation>エクスポート</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="271"/>
-        <source>Spell check</source>
-        <translation>スペルチェック</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="279"/>
-        <source>Default markup</source>
-        <translation>デフォルトマークアップ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="282"/>
-        <source>Formatting</source>
-        <translation>書式</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="323"/>
-        <source>Search</source>
-        <translation>検索</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="325"/>
-        <source>Case sensitively</source>
-        <translation>大文字と小文字を区別</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1141"/>
+        <location filename="tab.py" line="115"/>
         <source>New document</source>
         <translation>新規文書</translation>
     </message>
     <message>
-        <location filename="window.py" line="685"/>
+        <location filename="tab.py" line="121"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation>ファイルの内容を解析できません。&lt;a href=&quot;%s&quot;&gt;必要なモジュール&lt;/a&gt; がインストールされているか確認してください。</translation>
     </message>
+</context>
+<context>
+    <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="748"/>
+        <location filename="window.py" line="69"/>
+        <source>File toolbar</source>
+        <translation>ファイルツールバー</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="71"/>
+        <source>Edit toolbar</source>
+        <translation>編集ツールバー</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="73"/>
+        <source>Search toolbar</source>
+        <translation>検索ツールバー</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="77"/>
+        <source>New</source>
+        <translation>新規</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="80"/>
+        <source>Open</source>
+        <translation>開く</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="83"/>
+        <source>Set encoding</source>
+        <translation>文字エンコーディング</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1009"/>
+        <source>Reload</source>
+        <translation>再読み込み</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="89"/>
+        <source>Save</source>
+        <translation>保存</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="93"/>
+        <source>Save as</source>
+        <translation>名前を付けて保存</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="95"/>
+        <source>Next tab</source>
+        <translation>次のタブへ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="97"/>
+        <source>Previous tab</source>
+        <translation>前のタブへ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="99"/>
+        <source>Print</source>
+        <translation>印刷</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="102"/>
+        <source>Print preview</source>
+        <translation>印刷プレビュー</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="104"/>
+        <source>View HTML code</source>
+        <translation>HTMLコードを表示</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="105"/>
+        <source>Change editor font</source>
+        <translation>エディターのフォントを変更</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="107"/>
+        <source>Change preview font</source>
+        <translation>プレビューのフォントを変更</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="109"/>
+        <source>Find text</source>
+        <translation>テキストを検索</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="113"/>
+        <source>Preview</source>
+        <translation>プレビュー</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="123"/>
+        <source>Live preview</source>
+        <translation>ライブプレビュー</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="128"/>
+        <source>Table mode</source>
+        <translation>表組みモード</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="131"/>
+        <source>FakeVim mode</source>
+        <translation>擬似Vimモード</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="136"/>
+        <source>Fullscreen mode</source>
+        <translation>フルスクリーンモード</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="503"/>
+        <source>Preferences</source>
+        <translation>設定</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="146"/>
+        <source>Quit</source>
+        <translation>終了</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="149"/>
+        <source>Undo</source>
+        <translation>元に戻す</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="151"/>
+        <source>Redo</source>
+        <translation>やり直す</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="153"/>
+        <source>Copy</source>
+        <translation>コピー</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="155"/>
+        <source>Cut</source>
+        <translation>切り取り</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="157"/>
+        <source>Paste</source>
+        <translation>貼り付け</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="167"/>
+        <source>Enable</source>
+        <translation>有効</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="168"/>
+        <source>Set locale</source>
+        <translation>ロケールの設定</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="169"/>
+        <source>Use WebKit renderer</source>
+        <translation>WebKitレンダラーを使用</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="171"/>
+        <source>Show directory</source>
+        <translation>ディレクトリを表示</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="172"/>
+        <source>Next</source>
+        <translation>次へ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="174"/>
+        <source>Previous</source>
+        <translation>前へ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="176"/>
+        <source>Get help online</source>
+        <translation>オンラインでヘルプを読む</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="177"/>
+        <source>About ReText</source>
+        <translation>ReTextについて</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="180"/>
+        <source>About Qt</source>
+        <translation>Qtについて</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="200"/>
+        <source>Bold</source>
+        <translation>太字</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="202"/>
+        <source>Italic</source>
+        <translation>斜体</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="204"/>
+        <source>Underline</source>
+        <translation>下線</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="212"/>
+        <source>Tags</source>
+        <translation>タグ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="216"/>
+        <source>Symbols</source>
+        <translation>シンボル</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="223"/>
+        <source>File</source>
+        <translation>ファイル</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="224"/>
+        <source>Edit</source>
+        <translation>編集</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="225"/>
+        <source>Help</source>
+        <translation>ヘルプ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="228"/>
+        <source>Open recent</source>
+        <translation>最近使用したファイル</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="241"/>
+        <source>Export</source>
+        <translation>エクスポート</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="262"/>
+        <source>Spell check</source>
+        <translation>スペルチェック</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="270"/>
+        <source>Default markup</source>
+        <translation>デフォルトマークアップ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="273"/>
+        <source>Formatting</source>
+        <translation>書式</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="313"/>
+        <source>Search</source>
+        <translation>検索</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="315"/>
+        <source>Case sensitively</source>
+        <translation>大文字と小文字を区別</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="442"/>
+        <source>New document</source>
+        <translation>新規文書</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="591"/>
         <source>Please, save the file somewhere.</source>
         <translation>どこかにファイルを保存してください。</translation>
     </message>
     <message>
-        <location filename="window.py" line="868"/>
+        <location filename="window.py" line="711"/>
         <source>Select one or several files to open</source>
         <translation>開きたいファイル（複数可）を選択してください</translation>
     </message>
     <message>
-        <location filename="window.py" line="868"/>
+        <location filename="window.py" line="711"/>
         <source>Supported files</source>
         <translation>サポートされているファイル</translation>
     </message>
     <message>
-        <location filename="window.py" line="868"/>
+        <location filename="window.py" line="711"/>
         <source>All files (*)</source>
         <translation>すべてのファイル (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="927"/>
+        <location filename="window.py" line="750"/>
         <source>Select file encoding from the list:</source>
         <translation>ファイルの文字エンコーディングを選んでください：</translation>
     </message>
     <message>
-        <location filename="window.py" line="952"/>
+        <location filename="window.py" line="770"/>
         <source>Plain text (*.txt)</source>
         <translation>プレーンテキスト (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="955"/>
+        <location filename="window.py" line="773"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>%s ファイル</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="window.py" line="844"/>
         <source>Save file</source>
         <translation>ファイルを保存</translation>
     </message>
     <message>
-        <location filename="window.py" line="982"/>
+        <location filename="window.py" line="799"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>読み取り専用ファイルのため保存できません。</translation>
     </message>
     <message>
-        <location filename="window.py" line="1030"/>
+        <location filename="window.py" line="834"/>
         <source>Export document to ODT</source>
         <translation>文書をODTにエクスポート</translation>
     </message>
     <message>
-        <location filename="window.py" line="1030"/>
+        <location filename="window.py" line="834"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>OpenDocumentテキストファイル (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="window.py" line="844"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>HTMLファイル (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1062"/>
+        <location filename="window.py" line="866"/>
         <source>Export document to PDF</source>
         <translation>文書をPDFにエクスポート</translation>
     </message>
     <message>
-        <location filename="window.py" line="1062"/>
+        <location filename="window.py" line="866"/>
         <source>PDF files (*.pdf)</source>
         <translation>PDFファイル (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1079"/>
+        <location filename="window.py" line="883"/>
         <source>Print document</source>
         <translation>文書を印刷</translation>
     </message>
     <message>
-        <location filename="window.py" line="1100"/>
+        <location filename="window.py" line="904"/>
         <source>Export document</source>
         <translation>文書をエクスポート</translation>
     </message>
     <message>
-        <location filename="window.py" line="1119"/>
+        <location filename="window.py" line="923"/>
         <source>Failed to execute the command:</source>
         <translation>コマンドの実行に失敗しました:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1200"/>
+        <location filename="window.py" line="992"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
         <translation>このファイルは他のアプリケーションによって削除されました。
 終了する前にファイルを保存して下さい。</translation>
     </message>
     <message>
-        <location filename="window.py" line="1208"/>
+        <location filename="window.py" line="1000"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
@@ -507,49 +510,49 @@ Do you want to reload the file (this will discard all your changes)?
 </translation>
     </message>
     <message>
-        <location filename="window.py" line="1213"/>
+        <location filename="window.py" line="1005"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
         <translation>再読み込みを選択しない場合、データの消失を避けるために自動保存機能はこのセッションで無効になります。</translation>
     </message>
     <message>
-        <location filename="window.py" line="1237"/>
+        <location filename="window.py" line="1030"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>文書は変更されています。
 変更内容を保存しますか？</translation>
     </message>
     <message>
-        <location filename="window.py" line="1261"/>
+        <location filename="window.py" line="1055"/>
         <source>HTML code</source>
         <translation>HTMLコード</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>ReText %s (using PyMarkups %s)</source>
         <translation>ReText %s(PyMarkups %s 利用)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Markdown と reStructuredText のためのシンプルでパワフルなエディタ</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>作者: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>Website</source>
         <translation>Webサイト</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>Markdown syntax</source>
         <translation>Markdown 記法</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>reStructuredText syntax</source>
         <translation>reStructuredText 文法</translation>
     </message>
