@@ -3,82 +3,72 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Behavior</source>
         <translation>Понашање</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Automatically save documents</source>
         <translation>Аутоматски сачувај документе</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Restore window geometry</source>
         <translation>Упамти геометрију прозора</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
-        <source>Restore live preview state</source>
-        <translation>Упамти стање тренутног прегледа</translation>
-    </message>
-    <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Open external links in ReText window</source>
         <translation>Отварај спољне везе у РеТекст прозору</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Markdown syntax extensions (comma-separated)</source>
-        <translation>Проширења синтаксе Markdown (одвојено запетом)</translation>
+        <translation>Маркдаун проширења синтаксе (одвојено запетом)</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Editor</source>
         <translation>Уређивач</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Highlight current line</source>
         <translation>Истакни тренутну линију</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Show line numbers</source>
         <translation>Прикажи бројеве линија</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Tab key inserts spaces</source>
         <translation>Таб убацује размаке</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Tabulation width</source>
         <translation>Ширина табулације</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Display right margin at column</source>
         <translation>Прикажи десну маргину у колони</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Interface</source>
         <translation>Сучеље</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Icon theme name</source>
         <translation>Назив теме икона</translation>
     </message>
     <message>
-        <location filename="config.py" line="66"/>
-        <source>Color scheme file</source>
-        <translation>Фајл шеме боја</translation>
-    </message>
-    <message>
-        <location filename="config.py" line="66"/>
+        <location filename="config.py" line="67"/>
         <source>Stylesheet file</source>
         <translation>Фајл распореда</translation>
     </message>
@@ -87,16 +77,21 @@
         <source>Help</source>
         <translation>Помоћ</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Use live preview by default</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
     <message>
-        <location filename="config.py" line="33"/>
+        <location filename="config.py" line="34"/>
         <source>(none)</source>
         <translation>(ништа)</translation>
     </message>
     <message>
-        <location filename="config.py" line="40"/>
+        <location filename="config.py" line="41"/>
         <source>Select file to open</source>
         <translation>Изаберите фајл</translation>
     </message>
@@ -128,367 +123,385 @@
     </message>
 </context>
 <context>
-    <name>ReTextWindow</name>
+    <name>ReTextTab</name>
     <message>
-        <location filename="window.py" line="82"/>
-        <source>File toolbar</source>
-        <translation>Фајл алатна трака</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="84"/>
-        <source>Edit toolbar</source>
-        <translation>Уреди алатна трака</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="86"/>
-        <source>Search toolbar</source>
-        <translation>Алатна трака тражења</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="90"/>
-        <source>New</source>
-        <translation>Ново</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="93"/>
-        <source>Open</source>
-        <translation>Отвори</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="96"/>
-        <source>Set encoding</source>
-        <translation>Постави кодирање</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1217"/>
-        <source>Reload</source>
-        <translation>Учитај поново</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="101"/>
-        <source>Save</source>
-        <translation>Сачувај</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="105"/>
-        <source>Save as</source>
-        <translation>Сачувај као</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="107"/>
-        <source>Next tab</source>
-        <translation>Следећи језичак</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="109"/>
-        <source>Previous tab</source>
-        <translation>Претходни језичак</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="111"/>
-        <source>Print</source>
-        <translation>Штампај</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="114"/>
-        <source>Print preview</source>
-        <translation>Приказ штампе</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="116"/>
-        <source>View HTML code</source>
-        <translation>Погледај ХТМЛ код</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="121"/>
-        <source>Find text</source>
-        <translation>Нађи текст</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="125"/>
-        <source>Preview</source>
-        <translation>Преглед</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="135"/>
-        <source>Live preview</source>
-        <translation>Тренутни преглед</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="137"/>
-        <source>Table mode</source>
-        <translation>Режим табеле</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="140"/>
-        <source>FakeVim mode</source>
-        <translation>Лажни Вим режим</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="145"/>
-        <source>Fullscreen mode</source>
-        <translation>Режим пуног екрана</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="592"/>
-        <source>Preferences</source>
-        <translation>Подешавања</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="155"/>
-        <source>Quit</source>
-        <translation>Напусти</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="158"/>
-        <source>Undo</source>
-        <translation>Поништи</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="160"/>
-        <source>Redo</source>
-        <translation>Понови</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="162"/>
-        <source>Copy</source>
-        <translation>Копирај</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="164"/>
-        <source>Cut</source>
-        <translation>Исеци</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="166"/>
-        <source>Paste</source>
-        <translation>Налепи</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="176"/>
-        <source>Enable</source>
-        <translation>Укључи</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="177"/>
-        <source>Set locale</source>
-        <translation>Постави локалитет</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="178"/>
-        <source>Use WebKit renderer</source>
-        <translation>Користи ВебКит исцртавач</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="180"/>
-        <source>Show directory</source>
-        <translation>Прикажи директоријум</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="181"/>
-        <source>Next</source>
-        <translation>Следеће</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="183"/>
-        <source>Previous</source>
-        <translation>Претходно</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="185"/>
-        <source>Get help online</source>
-        <translation>Потражите помоћ на интернету</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="186"/>
-        <source>About ReText</source>
-        <translation>О програму ReText</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="189"/>
-        <source>About Qt</source>
-        <translation>О КуТ-у</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="209"/>
-        <source>Bold</source>
-        <translation>Подебљано</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="211"/>
-        <source>Italic</source>
-        <translation>Курзивно</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="213"/>
-        <source>Underline</source>
-        <translation>Подвучено</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="221"/>
-        <source>Tags</source>
-        <translation>Ознаке</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="225"/>
-        <source>Symbols</source>
-        <translation>Симболи</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="232"/>
-        <source>File</source>
-        <translation>Фајл</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="233"/>
-        <source>Edit</source>
-        <translation>Уређивање</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="234"/>
-        <source>Help</source>
-        <translation>Помоћ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="237"/>
-        <source>Open recent</source>
-        <translation>Отвори недавне</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="250"/>
-        <source>Export</source>
-        <translation>Извези</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="271"/>
-        <source>Spell check</source>
-        <translation>Провера правописа</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="279"/>
-        <source>Default markup</source>
-        <translation>Подразумевана маркација</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="282"/>
-        <source>Formatting</source>
-        <translation>Форматирање</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="323"/>
-        <source>Search</source>
-        <translation>Тражи</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="325"/>
-        <source>Case sensitively</source>
-        <translation>Осетљив на вел. слова</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1141"/>
+        <location filename="tab.py" line="115"/>
         <source>New document</source>
         <translation>Нови документ</translation>
     </message>
     <message>
-        <location filename="window.py" line="685"/>
+        <location filename="tab.py" line="121"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation>Не могу да рашчланим садржај фајла, Проверите да ли имате инсталиран &lt;a href=&quot;%s&quot;&gt;неопходан модул&lt;/a&gt;!</translation>
     </message>
+</context>
+<context>
+    <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="748"/>
+        <location filename="window.py" line="69"/>
+        <source>File toolbar</source>
+        <translation>Фајл алатна трака</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="71"/>
+        <source>Edit toolbar</source>
+        <translation>Уреди алатна трака</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="73"/>
+        <source>Search toolbar</source>
+        <translation>Алатна трака тражења</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="77"/>
+        <source>New</source>
+        <translation>Ново</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="80"/>
+        <source>Open</source>
+        <translation>Отвори</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="83"/>
+        <source>Set encoding</source>
+        <translation>Постави кодирање</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1009"/>
+        <source>Reload</source>
+        <translation>Учитај поново</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="89"/>
+        <source>Save</source>
+        <translation>Сачувај</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="93"/>
+        <source>Save as</source>
+        <translation>Сачувај као</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="95"/>
+        <source>Next tab</source>
+        <translation>Следећи језичак</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="97"/>
+        <source>Previous tab</source>
+        <translation>Претходни језичак</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="99"/>
+        <source>Print</source>
+        <translation>Штампај</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="102"/>
+        <source>Print preview</source>
+        <translation>Приказ штампе</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="104"/>
+        <source>View HTML code</source>
+        <translation>Погледај ХТМЛ код</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="105"/>
+        <source>Change editor font</source>
+        <translation>Измени фонт уређивача</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="107"/>
+        <source>Change preview font</source>
+        <translation>Измени фонт прегледа</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="109"/>
+        <source>Find text</source>
+        <translation>Нађи текст</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="113"/>
+        <source>Preview</source>
+        <translation>Преглед</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="123"/>
+        <source>Live preview</source>
+        <translation>Тренутни преглед</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="128"/>
+        <source>Table mode</source>
+        <translation>Режим табеле</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="131"/>
+        <source>FakeVim mode</source>
+        <translation>Лажни Вим режим</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="136"/>
+        <source>Fullscreen mode</source>
+        <translation>Режим пуног екрана</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="503"/>
+        <source>Preferences</source>
+        <translation>Подешавања</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="146"/>
+        <source>Quit</source>
+        <translation>Напусти</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="149"/>
+        <source>Undo</source>
+        <translation>Поништи</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="151"/>
+        <source>Redo</source>
+        <translation>Понови</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="153"/>
+        <source>Copy</source>
+        <translation>Копирај</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="155"/>
+        <source>Cut</source>
+        <translation>Исеци</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="157"/>
+        <source>Paste</source>
+        <translation>Налепи</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="167"/>
+        <source>Enable</source>
+        <translation>Укључи</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="168"/>
+        <source>Set locale</source>
+        <translation>Постави локалитет</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="169"/>
+        <source>Use WebKit renderer</source>
+        <translation>Користи ВебКит исцртавач</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="171"/>
+        <source>Show directory</source>
+        <translation>Прикажи директоријум</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="172"/>
+        <source>Next</source>
+        <translation>Следеће</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="174"/>
+        <source>Previous</source>
+        <translation>Претходно</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="176"/>
+        <source>Get help online</source>
+        <translation>Потражите помоћ на интернету</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="177"/>
+        <source>About ReText</source>
+        <translation>О РеТексту</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="180"/>
+        <source>About Qt</source>
+        <translation>О КуТ-у</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="200"/>
+        <source>Bold</source>
+        <translation>Подебљано</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="202"/>
+        <source>Italic</source>
+        <translation>Курзивно</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="204"/>
+        <source>Underline</source>
+        <translation>Подвучено</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="212"/>
+        <source>Tags</source>
+        <translation>Ознаке</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="216"/>
+        <source>Symbols</source>
+        <translation>Симболи</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="223"/>
+        <source>File</source>
+        <translation>Фајл</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="224"/>
+        <source>Edit</source>
+        <translation>Уређивање</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="225"/>
+        <source>Help</source>
+        <translation>Помоћ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="228"/>
+        <source>Open recent</source>
+        <translation>Отвори недавне</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="241"/>
+        <source>Export</source>
+        <translation>Извези</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="262"/>
+        <source>Spell check</source>
+        <translation>Провера правописа</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="270"/>
+        <source>Default markup</source>
+        <translation>Подразумевана маркација</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="273"/>
+        <source>Formatting</source>
+        <translation>Форматирање</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="313"/>
+        <source>Search</source>
+        <translation>Тражи</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="315"/>
+        <source>Case sensitively</source>
+        <translation>Осетљив на вел. слова</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="442"/>
+        <source>New document</source>
+        <translation>Нови документ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="591"/>
         <source>Please, save the file somewhere.</source>
         <translation>Сачувајте фајл негде.</translation>
     </message>
     <message>
-        <location filename="window.py" line="868"/>
+        <location filename="window.py" line="711"/>
         <source>Select one or several files to open</source>
         <translation>Изаберите један или више фајлова за отварање</translation>
     </message>
     <message>
-        <location filename="window.py" line="868"/>
+        <location filename="window.py" line="711"/>
         <source>Supported files</source>
         <translation>Подржани фајлови</translation>
     </message>
     <message>
-        <location filename="window.py" line="868"/>
+        <location filename="window.py" line="711"/>
         <source>All files (*)</source>
         <translation>Сви фајлови (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="927"/>
+        <location filename="window.py" line="750"/>
         <source>Select file encoding from the list:</source>
         <translation>Са листе изаберите кодирање фајла:</translation>
     </message>
     <message>
-        <location filename="window.py" line="952"/>
+        <location filename="window.py" line="770"/>
         <source>Plain text (*.txt)</source>
         <translation>Обичан текст (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="955"/>
+        <location filename="window.py" line="773"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>%s фајлови</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="window.py" line="844"/>
         <source>Save file</source>
         <translation>Сачувај фајл</translation>
     </message>
     <message>
-        <location filename="window.py" line="982"/>
+        <location filename="window.py" line="799"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Не могу да сачувам јер је фајл само за читање!</translation>
     </message>
     <message>
-        <location filename="window.py" line="1030"/>
+        <location filename="window.py" line="834"/>
         <source>Export document to ODT</source>
         <translation>Извези документ у ОДТ</translation>
     </message>
     <message>
-        <location filename="window.py" line="1030"/>
+        <location filename="window.py" line="834"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>ОпенДокумент текстуални фајл (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="window.py" line="844"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>ХТМЛ фајлови (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1062"/>
+        <location filename="window.py" line="866"/>
         <source>Export document to PDF</source>
         <translation>Извези документ у ПДФ</translation>
     </message>
     <message>
-        <location filename="window.py" line="1062"/>
+        <location filename="window.py" line="866"/>
         <source>PDF files (*.pdf)</source>
         <translation>ПДФ фајлови (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1079"/>
+        <location filename="window.py" line="883"/>
         <source>Print document</source>
         <translation>Штампај документ</translation>
     </message>
     <message>
-        <location filename="window.py" line="1100"/>
+        <location filename="window.py" line="904"/>
         <source>Export document</source>
         <translation>Извези документ</translation>
     </message>
     <message>
-        <location filename="window.py" line="1119"/>
+        <location filename="window.py" line="923"/>
         <source>Failed to execute the command:</source>
         <translation>Неуспело извршење команде:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1200"/>
+        <location filename="window.py" line="992"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
         <translation>Овај фајл је обрисала друга апликације.
 Сачувајте га пре него што изађете.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1208"/>
+        <location filename="window.py" line="1000"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
@@ -496,61 +509,51 @@ Do you want to reload the file (this will discard all your changes)?
 Желите ли да га поново учитате? (ово ће поништити све ваше измене)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1213"/>
+        <location filename="window.py" line="1005"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
         <translation>Ако изаберете да не учитате поново, аутоматско чување биће искључено за ову сесију да би се спречио губитак података.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1237"/>
+        <location filename="window.py" line="1030"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Документ је измењен.
 Желите ли да сачувате ваше измене?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1261"/>
+        <location filename="window.py" line="1055"/>
         <source>HTML code</source>
         <translation>ХТМЛ код</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
-        <source>Simple but powerful editor for Markdown and reStructuredText</source>
-        <translation>Једноставан али моћан уређивач за Markdown и reStructuredText</translation>
+        <location filename="window.py" line="1066"/>
+        <source>ReText %s (using PyMarkups %s)</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
+        <source>Simple but powerful editor for Markdown and reStructuredText</source>
+        <translation>Једноставан али моћан уређивач за Маркдаун и реструктуирани текст</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1066"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Аутор: Дмитриј Шачнев (Dmitry Shachnev), 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>Website</source>
         <translation>Веб сајт</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>Markdown syntax</source>
-        <translation>Синтакса Markdown</translation>
+        <translation>Маркдаун синтакса</translation>
     </message>
     <message>
-        <location filename="window.py" line="1272"/>
+        <location filename="window.py" line="1066"/>
         <source>reStructuredText syntax</source>
-        <translation>Синтакса reStructuredText</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="117"/>
-        <source>Change editor font</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="119"/>
-        <source>Change preview font</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1272"/>
-        <source>ReText %s (using PyMarkups %s)</source>
-        <translation type="unfinished"></translation>
+        <translation>Синтакса реструктуираног текста</translation>
     </message>
 </context>
 </TS>
